@@ -240,11 +240,11 @@
 #' #~~~~~~~~~~~~~~~~~~~~~~~~
 #' #### Step 3 --- Optimize N over the rows in design
 #'
-#' # (For debugging) may want to see if simulation code works as intended first
-#' # for some given set of inputs
-#' runSimulation(design=createDesign(N=100, d=.8, sig.level=.05),
-#'               replications=10, generate=Generate, analyse=Analyse,
-#'               summarise=Summarise)
+#' ### (For debugging) may want to see if simulation code works as intended first
+#' ### for some given set of inputs
+#' # runSimulation(design=createDesign(N=100, d=.8, sig.level=.05),
+#' #              replications=10, generate=Generate, analyse=Analyse,
+#' #              summarise=Summarise)
 #'
 #' # Initial search between N = [10,500] for each row using the default
 #'    # integer solver (integer = TRUE). In this example, b = target power
@@ -280,15 +280,15 @@
 #' pwr.t.test(d=.5, n=N[2])
 #' pwr.t.test(d=.8, n=N[3])
 #'
-#' # failing analytic formula, confirm results with more precise
-#' #  simulation via runSimulation()
-#' #  (not required, if accuracy is important then ProBABLI should be run longer)
-#' csolved <- solved
-#' csolved$N <- ceiling(solved$N)
-#' confirm <- runSimulation(design=csolved, replications=10000, parallel=TRUE,
-#'                          generate=Generate, analyse=Analyse,
-#'                          summarise=Summarise)
-#' confirm
+#' ### failing analytic formula, confirm results with more precise
+#' ###  simulation via runSimulation()
+#' ###  (not required, if accuracy is important then ProBABLI should be run longer)
+#' # csolved <- solved
+#' # csolved$N <- ceiling(solved$N)
+#' # confirm <- runSimulation(design=csolved, replications=10000, parallel=TRUE,
+#' #                         generate=Generate, analyse=Analyse,
+#' #                         summarise=Summarise)
+#' # confirm
 #'
 #' # Alternatively, and more realistically, the wait.time argument can be used
 #' # to specify how long the user is willing to wait for a final estimate.
@@ -360,12 +360,13 @@
 #' pwr.t.test(n=50, d = solved$d[2])
 #' pwr.t.test(n=25, d = solved$d[3])
 #'
-#' # failing analytic formula, confirm results with more precise
-#' #  simulation via runSimulation()
-#' confirm <- runSimulation(design=solved, replications=10000, parallel=TRUE,
-#'                          generate=Generate, analyse=Analyse,
-#'                          summarise=Summarise)
-#' confirm
+#' ### failing analytic formula, confirm results with more precise
+#' ###  simulation via runSimulation() (not required; if accuracy is important
+#' ###  PROBABLI should just be run longer)
+#' # confirm <- runSimulation(design=solved, replications=10000, parallel=TRUE,
+#' #                         generate=Generate, analyse=Analyse,
+#' #                         summarise=Summarise)
+#' # confirm
 #'
 #'
 #' #------------------------------------------------
@@ -411,12 +412,13 @@
 #' pwr.t.test(n=50, d = .5, sig.level=solved$sig.level[2])
 #' pwr.t.test(n=50, d = .8, sig.level=solved$sig.level[3])
 #'
-#' # failing analytic formula, confirm results with more precise
-#' #  simulation via runSimulation()
-#' confirm <- runSimulation(design=solved, replications=10000, parallel=TRUE,
-#'                          generate=Generate, analyse=Analyse,
-#'                          summarise=Summarise)
-#' confirm
+#' ### failing analytic formula, confirm results with more precise
+#' ###  simulation via runSimulation() (not required; if accuracy is important
+#' ###  PROBABLI should just be run longer)
+#' # confirm <- runSimulation(design=solved, replications=10000, parallel=TRUE,
+#' #                         generate=Generate, analyse=Analyse,
+#' #                         summarise=Summarise)
+#' # confirm
 #'
 #' }
 SimSolve <- function(design, interval, b, generate, analyse, summarise,
@@ -575,6 +577,12 @@ SimSolve <- function(design, interval, b, generate, analyse, summarise,
             message(paste0('\nContinuing at design row ', start,
                            '. If not intended, terminate and use SimClean()'))
     }
+    if(integer){
+        if(!all(apply(interval, 1L, function(int)
+            !all(as.integer(int) != int))))
+            stop(c('Search interval contains decimals while algorithm is currently',
+                   ' using integer=TRUE search'), call.=FALSE)
+    }
     for(i in start:nrow(design)){
         if(verbose){
             cat(sprintf('\n\n#############\nDesign row %s:\n\n', i))
